==> nextcloud-24.0.9.tgz: nextcloud/apps/systemtags/l10n/de_DE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Schlagwortname ist leer",
    "Update" : "Aktualisieren",
    "Create" : "Erstellen",
    "Select tag …" : "Schlagwort wählen …",
    "System tag %1$s added by the system" : "System-Schlagwort %1$s vom System hinzugefügt",
    "Added system tag {systemtag}" : "System-Schlagwort {systemtag} hinzugefügt",
    "Added system tag %1$s" : "System-Schlagwort %1$s hinzugefügt",
    "%1$s added system tag %2$s" : "%1$s hat das System-Schlagwort %2$s hinzugefügt",
    "{actor} added system tag {systemtag}" : "{actor} hat den System-Schlagwort {systemtag} hinzugefügt",
    "System tag %1$s removed by the system" : "System-Schlagwort %1$s wurde vom System entfernt",
    "Removed system tag {systemtag}" : "System-Schlagwort {systemtag} entfernt",
    "Removed system tag %1$s" : "System-Schlagwort %1$s entfernt",
    "%1$s removed system tag %2$s" : "%1$s hat das System-Schlagwort %2$s entfernt",
    "{actor} removed system tag {systemtag}" : "{actor} hat das System-Schlagwort {systemtag} entfernt",
    "You created system tag %1$s" : "Sie haben das System-Schlagwort %1$s erstellt",
    "You created system tag {systemtag}" : "Sie haben das System-Schlagwort {systemtag} erstellt",
    "%1$s created system tag %2$s" : "%1$s hat das System-Schlagwort %2$s erstellt",
    "{actor} created system tag {systemtag}" : "{actor} hat das System-Schlagwort {systemtag} erstellt",
    "You deleted system tag %1$s" : "Sie haben das System-Schlagwort %1$s gelöscht",
    "You deleted system tag {systemtag}" : "Sie haben das System-Schlagwort {systemtag} gelöscht",
    "%1$s deleted system tag %2$s" : "%1$s hat das System-Schlagwort %2$s gelöscht",
    "{actor} deleted system tag {systemtag}" : "{actor} hat das System-Schlagwort {systemtag} gelöscht",
    "You updated system tag %2$s to %1$s" : "Sie haben das System-Schlagwort %2$s zu %1$s aktualisiert",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Sie haben das System-Schlagwort {oldsystemtag} zu {newsystemtag} aktualisiert",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat das System-Schlagwort von %3$s zu %2$s aktualisiert",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} hat das System-Schlagwort {oldsystemtag} zu {newsystemtag} aktualisiert",
    "System tag %2$s was added to %1$s by the system" : "System-Schlagwort %2$s wurde %1$s vom System hinzugefügt",
    "System tag {systemtag} was added to {file} by the system" : "System-Schlagwort {systemtag} wurde {file} vom System hinzugefügt",
    "You added system tag %2$s to %1$s" : "Sie haben das System-Schlagwort %2$s zu %1$s hinzugefügt",
    "You added system tag {systemtag} to {file}" : "Sie haben das System-Schlagwort {systemtag} zu {file} hinzugefügt",
    "%1$s added system tag %3$s to %2$s" : "%1$s hat das System-Schlagwort %3$s zu %2$s hinzugefügt",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hat das System-Schlagwort {systemtag} zu {file} hinzugefügt",
    "System tag %2$s was removed from %1$s by the system" : "System-Schlagwort %2$s wurde vom System aus %1$s entfernt",
    "System tag {systemtag} was removed from {file} by the system" : "System-Schlagwort {systemtag} wurde vom System von {file} entfernt",
    "You removed system tag %2$s from %1$s" : "Sie haben das System-Schlagwort %2$s von %1$s entfernt",
    "You removed system tag {systemtag} from {file}" : "Sie haben das System-Schlagwort {systemtag} von {file} entfernt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hat das System-Schlagwort %3$s von %2$s entfernt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hat das System-Schlagwort {systemtag} von {file} entfernt",
    "%s (restricted)" : "%s (eingeschränkt)",
    "%s (invisible)" : "%s (unsichtbar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Schlagwort</strong> für eine Datei wurde geändert",
    "Tags" : "Schlagwörter",
    "All tagged %s …" : "Alle Schlagwörter %s hinzugefügt ....",
    "tagged %s" : "Schlagwort %s hinzugefügt",
    "Collaborative tags" : "Kollaborative Schlagwörter",
    "Collaborative tagging functionality which shares tags among users." : "Gemeinschaftliche Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Gemeinschaftliche Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt. Sehr gut für Gruppen.\n\t(Wenn Sie ein Anbieter mit einer Mehrkundeninstallation sind, so ist angeraten diese App zu deaktiveren, da die Schlagworte mit allen Kunden geteilt werden.)",
    "Tagged files" : "Mit Schlagwörter versehene Dateien",
    "Select tags to filter by" : "Wählen Sie Schlagwörter nach denen gefiltert werden soll",
    "No tags found" : "Keine Schlagwörter gefunden",
    "Please select tags to filter by" : "Bitte wählen Sie Schlagwörter, nach denen gefiltert werden soll",
    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Schlagwörter gefunden",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Gemeinschaftliche Schlagworte sind für alle Benutzer verfügbar. Eingeschränkte Schlagworte sind für alle Benutzer sichtbar, können jedoch nicht zugewiesen werden. Nicht sichtbare Schlagworte sind für interne Verwendung und können vom Benutzer nicht eingesehen und nicht zugewiesen werden.",
    "Create a new tag" : "Neues Schlagwort erstellen",
    "Name" : "Name",
    "Public" : "Öffentlich",
    "Restricted" : "Eingeschränkt",
    "Invisible" : "Nicht sichtbar",
    "Delete" : "Löschen",
    "Reset" : "Zurücksetzen",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Size" : "Größe",
    "Modified" : "Geändert"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.12.tgz: nextcloud/apps/systemtags/l10n/de_DE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Schlagwortname ist leer",
    "Update" : "Aktualisieren",
    "Create" : "Erstellen",
    "Select tag …" : "Schlagwort wählen …",
    "System tag %1$s added by the system" : "System-Schlagwort %1$s vom System hinzugefügt",
    "Added system tag {systemtag}" : "System-Schlagwort {systemtag} hinzugefügt",
    "Added system tag %1$s" : "System-Schlagwort %1$s hinzugefügt",
    "%1$s added system tag %2$s" : "%1$s hat das System-Schlagwort %2$s hinzugefügt",
    "{actor} added system tag {systemtag}" : "{actor} hat den System-Schlagwort {systemtag} hinzugefügt",
    "System tag %1$s removed by the system" : "System-Schlagwort %1$s wurde vom System entfernt",
    "Removed system tag {systemtag}" : "System-Schlagwort {systemtag} entfernt",
    "Removed system tag %1$s" : "System-Schlagwort %1$s entfernt",
    "%1$s removed system tag %2$s" : "%1$s hat das System-Schlagwort %2$s entfernt",
    "{actor} removed system tag {systemtag}" : "{actor} hat das System-Schlagwort {systemtag} entfernt",
    "You created system tag %1$s" : "Sie haben das System-Schlagwort %1$s erstellt",
    "You created system tag {systemtag}" : "Sie haben das System-Schlagwort {systemtag} erstellt",
    "%1$s created system tag %2$s" : "%1$s hat das System-Schlagwort %2$s erstellt",
    "{actor} created system tag {systemtag}" : "{actor} hat das System-Schlagwort {systemtag} erstellt",
    "You deleted system tag %1$s" : "Sie haben das System-Schlagwort %1$s gelöscht",
    "You deleted system tag {systemtag}" : "Sie haben das System-Schlagwort {systemtag} gelöscht",
    "%1$s deleted system tag %2$s" : "%1$s hat das System-Schlagwort %2$s gelöscht",
    "{actor} deleted system tag {systemtag}" : "{actor} hat das System-Schlagwort {systemtag} gelöscht",
    "You updated system tag %2$s to %1$s" : "Sie haben das System-Schlagwort %2$s zu %1$s aktualisiert",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Sie haben das System-Schlagwort {oldsystemtag} zu {newsystemtag} aktualisiert",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat das System-Schlagwort von %3$s zu %2$s aktualisiert",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} hat das System-Schlagwort {oldsystemtag} zu {newsystemtag} aktualisiert",
    "System tag %2$s was added to %1$s by the system" : "System-Schlagwort %2$s wurde %1$s vom System hinzugefügt",
    "System tag {systemtag} was added to {file} by the system" : "System-Schlagwort {systemtag} wurde {file} vom System hinzugefügt",
    "You added system tag %2$s to %1$s" : "Sie haben das System-Schlagwort %2$s zu %1$s hinzugefügt",
    "You added system tag {systemtag} to {file}" : "Sie haben das System-Schlagwort {systemtag} zu {file} hinzugefügt",
    "%1$s added system tag %3$s to %2$s" : "%1$s hat das System-Schlagwort %3$s zu %2$s hinzugefügt",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hat das System-Schlagwort {systemtag} zu {file} hinzugefügt",
    "System tag %2$s was removed from %1$s by the system" : "System-Schlagwort %2$s wurde vom System aus %1$s entfernt",
    "System tag {systemtag} was removed from {file} by the system" : "System-Schlagwort {systemtag} wurde vom System von {file} entfernt",
    "You removed system tag %2$s from %1$s" : "Sie haben das System-Schlagwort %2$s von %1$s entfernt",
    "You removed system tag {systemtag} from {file}" : "Sie haben das System-Schlagwort {systemtag} von {file} entfernt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hat das System-Schlagwort %3$s von %2$s entfernt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hat das System-Schlagwort {systemtag} von {file} entfernt",
    "%s (restricted)" : "%s (eingeschränkt)",
    "%s (invisible)" : "%s (unsichtbar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Schlagwort</strong> für eine Datei wurde geändert",
    "Tags" : "Schlagworte",
    "All tagged %s …" : "Alle Schlagwort %s hinzugefügt ....",
    "tagged %s" : "Schlagwort %s hinzugefügt",
    "Collaborative tags" : "Kollaborative Schlagworte",
    "Collaborative tagging functionality which shares tags among users." : "Gemeinschaftliche Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Gemeinschaftliche Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt. Sehr gut für Gruppen.\n\t(Wenn Sie ein Anbieter mit einer Mehrkundeninstallation sind, so ist angeraten diese App zu deaktiveren, da die Schlagworte mit allen Kunden geteilt werden.)",
    "Tagged files" : "Mit Schlagworten versehene Dateien",
    "Select tags to filter by" : "Wählen Sie Schlagworte nach denen gefiltert werden soll",
    "No tags found" : "Keine Schlagworte gefunden",
    "Please select tags to filter by" : "Bitte wählen Sie Schlagworte, nach denen gefiltert werden soll",
    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Schlagworte gefunden",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Gemeinschaftliche Schlagworte sind für alle Benutzer verfügbar. Eingeschränkte Schlagworte sind für alle Benutzer sichtbar, können jedoch nicht zugewiesen werden. Nicht sichtbare Schlagworte sind für interne Verwendung und können vom Benutzer nicht eingesehen und nicht zugewiesen werden.",
    "Create a new tag" : "Neues Schlagwort erstellen",
    "Name" : "Name",
    "Public" : "Öffentlich",
    "Restricted" : "Eingeschränkt",
    "Invisible" : "Nicht sichtbar",
    "Delete" : "Löschen",
    "Reset" : "Zurücksetzen",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Size" : "Größe",
    "Modified" : "Geändert"
},
"nplurals=2; plural=(n != 1);");
